@@ -73,20 +73,20 @@ LWP::Debug - deprecated
 
 =head1 DESCRIPTION
 
-LWP::Debug used to provide tracing facilities, but these are not used
+LWP::Debug is used to provide tracing facilities, but these are not used
 by LWP any more.  The code in this module is kept around
-(undocumented) so that 3rd party code that happen to use the old
+(undocumented) so that 3rd party code that happens to use the old
 interfaces continue to run.
 
 One useful feature that LWP::Debug provided (in an imprecise and
 troublesome way) was network traffic monitoring.  The following
-section provide some hints about recommened replacements.
+section provides some hints about recommended replacements.
 
 =head2 Network traffic monitoring
 
 The best way to monitor the network traffic that LWP generates is to
 use an external TCP monitoring program.  The Wireshark program
-(L<http://www.wireshark.org/>) is higly recommended for this.
+(L<http://www.wireshark.org/>) is highly recommended for this.
 
 Another approach it to use a debugging HTTP proxy server and make
 LWP direct all its traffic via this one.  Call C<< $ua->proxy >> to
