@@ -17,6 +17,14 @@ sub _new_socket
 {
     my($self, $host, $port, $timeout) = @_;
 
+    # IPv6 literal IP address should be [bracketed] to remove
+    # ambiguity between ip address and port number.
+    # Extra cautious to ensure that $host is _just_ an IPv6 address
+    # (at least as best as we can tell).
+    if ( ($host =~ /:/) && ($host =~ /^[0-9a-f:.]+$/i) ) {
+      $host = "[$host]";
+    }
+
     local($^W) = 0;  # IO::Socket::INET can be noisy
     my $sock = $self->socket_class->new(PeerAddr => $host,
 					PeerPort => $port,
